@@ -14,7 +14,7 @@ import logging
 
 from bamboo_engine import states
 from bamboo_engine.context import Context
-from bamboo_engine.eri import ProcessInfo, NodeType, ContextValue, ContextValueType, Data
+from bamboo_engine.eri import ProcessInfo, NodeType, ContextValue, ContextValueType
 from bamboo_engine.exceptions import NotFoundError
 from bamboo_engine.handler import register_handler, NodeHandler, ExecuteResult
 
@@ -23,9 +23,7 @@ logger = logging.getLogger("bamboo_engine")
 
 @register_handler(NodeType.EmptyStartEvent)
 class EmptyStartEventHandler(NodeHandler):
-    def execute(
-        self, process_info: ProcessInfo, loop: int, inner_loop: int, version: str
-    ) -> ExecuteResult:
+    def execute(self, process_info: ProcessInfo, loop: int, inner_loop: int, version: str) -> ExecuteResult:
         """
         节点的 execute 处理逻辑
 
@@ -71,9 +69,7 @@ class EmptyStartEventHandler(NodeHandler):
             logger.info(f"{top_pipeline_id} pre_render_keys results are: {upsert_context_dict}")
             self.runtime.upsert_plain_context_values(top_pipeline_id, upsert_context_dict)
 
-        self.runtime.set_state(
-            node_id=self.node.id, to_state=states.FINISHED, set_archive_time=True
-        )
+        self.runtime.set_state(node_id=self.node.id, to_state=states.FINISHED, set_archive_time=True)
 
         return ExecuteResult(
             should_sleep=False,
